@@ -6,6 +6,8 @@
 
 import * as string from './string.js'
 import * as env from './environment.js'
+import * as array from './array.js'
+import * as math from './math.js'
 import * as encoding from './encoding.js'
 import * as decoding from './decoding.js'
 
@@ -81,6 +83,38 @@ export const toBase64 = env.isBrowser ? toBase64Browser : toBase64Node
 /* c8 ignore next */
 export const fromBase64 = env.isBrowser ? fromBase64Browser : fromBase64Node
 
+/**
+ * Implements base64url - see https://datatracker.ietf.org/doc/html/rfc4648#section-5
+ * @param {Uint8Array} buf
+ */
+export const toBase64UrlEncoded = buf => toBase64(buf).replaceAll('+', '-').replaceAll('/', '_').replaceAll('=', '')
+
+/**
+ * @param {string} base64
+ */
+export const fromBase64UrlEncoded = base64 => fromBase64(base64.replaceAll('-', '+').replaceAll('_', '/'))
+
+/**
+ * Base64 is always a more efficient choice. This exists for utility purposes only.
+ *
+ * @param {Uint8Array} buf
+ */
+export const toHexString = buf => array.map(buf, b => b.toString(16).padStart(2, '0')).join('')
+
+/**
+ * Note: This function expects that the hex doesn't start with 0x..
+ *
+ * @param {string} hex
+ */
+export const fromHexString = hex => {
+  const hlen = hex.length
+  const buf = new Uint8Array(math.ceil(hlen / 2))
+  for (let i = 0; i < hlen; i += 2) {
+    buf[buf.length - i / 2 - 1] = Number.parseInt(hex.slice(hlen - i - 2, hlen - i), 16)
+  }
+  return buf
+}
+
 /**
  * Copy the content of an Uint8Array view to a new ArrayBuffer.
  *
@@ -113,3 +147,20 @@ export const encodeAny = data => {
  * @return {any}
  */
 export const decodeAny = buf => decoding.readAny(decoding.createDecoder(buf))
+
+/**
+ * Shift Byte Array {N} bits to the left. Does not expand byte array.
+ *
+ * @param {Uint8Array} bs
+ * @param {number} N should be in the range of [0-7]
+ */
+export const shiftNBitsLeft = (bs, N) => {
+  if (N === 0) return bs
+  bs = new Uint8Array(bs)
+  bs[0] <<= N
+  for (let i = 1; i < bs.length; i++) {
+    bs[i - 1] |= bs[i] >>> (8 - N)
+    bs[i] <<= N
+  }
+  return bs
+}
