@@ -5,58 +5,37 @@
  */
 
 import * as env from './environment.js'
-import * as symbol from './symbol.js'
+import * as set from './set.js'
 import * as pair from './pair.js'
 import * as dom from './dom.js'
 import * as json from './json.js'
 import * as map from './map.js'
 import * as eventloop from './eventloop.js'
 import * as math from './math.js'
-import * as time from './time.js'
-import * as func from './function.js'
+import * as common from './logging.common.js'
 
-export const BOLD = symbol.create()
-export const UNBOLD = symbol.create()
-export const BLUE = symbol.create()
-export const GREY = symbol.create()
-export const GREEN = symbol.create()
-export const RED = symbol.create()
-export const PURPLE = symbol.create()
-export const ORANGE = symbol.create()
-export const UNCOLOR = symbol.create()
+export { BOLD, UNBOLD, BLUE, GREY, GREEN, RED, PURPLE, ORANGE, UNCOLOR } from './logging.common.js'
 
 /**
  * @type {Object<Symbol,pair.Pair<string,string>>}
  */
 const _browserStyleMap = {
-  [BOLD]: pair.create('font-weight', 'bold'),
-  [UNBOLD]: pair.create('font-weight', 'normal'),
-  [BLUE]: pair.create('color', 'blue'),
-  [GREEN]: pair.create('color', 'green'),
-  [GREY]: pair.create('color', 'grey'),
-  [RED]: pair.create('color', 'red'),
-  [PURPLE]: pair.create('color', 'purple'),
-  [ORANGE]: pair.create('color', 'orange'), // not well supported in chrome when debugging node with inspector - TODO: deprecate
-  [UNCOLOR]: pair.create('color', 'black')
+  [common.BOLD]: pair.create('font-weight', 'bold'),
+  [common.UNBOLD]: pair.create('font-weight', 'normal'),
+  [common.BLUE]: pair.create('color', 'blue'),
+  [common.GREEN]: pair.create('color', 'green'),
+  [common.GREY]: pair.create('color', 'grey'),
+  [common.RED]: pair.create('color', 'red'),
+  [common.PURPLE]: pair.create('color', 'purple'),
+  [common.ORANGE]: pair.create('color', 'orange'), // not well supported in chrome when debugging node with inspector - TODO: deprecate
+  [common.UNCOLOR]: pair.create('color', 'black')
 }
 
-const _nodeStyleMap = {
-  [BOLD]: '\u001b[1m',
-  [UNBOLD]: '\u001b[2m',
-  [BLUE]: '\x1b[34m',
-  [GREEN]: '\x1b[32m',
-  [GREY]: '\u001b[37m',
-  [RED]: '\x1b[31m',
-  [PURPLE]: '\x1b[35m',
-  [ORANGE]: '\x1b[38;5;208m',
-  [UNCOLOR]: '\x1b[0m'
-}
-
-/* istanbul ignore next */
 /**
  * @param {Array<string|Symbol|Object|number>} args
  * @return {Array<string|object|number>}
  */
+/* c8 ignore start */
 const computeBrowserLoggingArgs = (args) => {
   const strBuilder = []
   const styles = []
@@ -67,7 +46,6 @@ const computeBrowserLoggingArgs = (args) => {
   let logArgs = []
   // try with formatting until we find something unsupported
   let i = 0
-
   for (; i < args.length; i++) {
     const arg = args[i]
     // @ts-ignore
@@ -88,7 +66,6 @@ const computeBrowserLoggingArgs = (args) => {
       }
     }
   }
-
   if (i > 0) {
     // create logArgs with what we have so far
     logArgs = styles
@@ -103,129 +80,49 @@ const computeBrowserLoggingArgs = (args) => {
   }
   return logArgs
 }
+/* c8 ignore stop */
 
-/* istanbul ignore next */
-/**
- * @param {Array<string|Symbol|Object|number>} args
- * @return {Array<string|object|number>}
- */
-const computeNoColorLoggingArgs = args => {
-  const strBuilder = []
-  const logArgs = []
-
-  // try with formatting until we find something unsupported
-  let i = 0
-
-  for (; i < args.length; i++) {
-    const arg = args[i]
-    // @ts-ignore
-    const style = _nodeStyleMap[arg]
-    if (style === undefined) {
-      if (arg.constructor === String || arg.constructor === Number) {
-        strBuilder.push(arg)
-      } else {
-        break
-      }
-    }
-  }
-  if (i > 0) {
-    logArgs.push(strBuilder.join(''))
-  }
-  // append the rest
-  for (; i < args.length; i++) {
-    const arg = args[i]
-    /* istanbul ignore else */
-    if (!(arg instanceof Symbol)) {
-      if (arg.constructor === Object) {
-        logArgs.push(JSON.stringify(arg))
-      } else {
-        logArgs.push(arg)
-      }
-    }
-  }
-  return logArgs
-}
-
-/* istanbul ignore next */
-/**
- * @param {Array<string|Symbol|Object|number>} args
- * @return {Array<string|object|number>}
- */
-const computeNodeLoggingArgs = (args) => {
-  const strBuilder = []
-  const logArgs = []
-
-  // try with formatting until we find something unsupported
-  let i = 0
-
-  for (; i < args.length; i++) {
-    const arg = args[i]
-    // @ts-ignore
-    const style = _nodeStyleMap[arg]
-    if (style !== undefined) {
-      strBuilder.push(style)
-    } else {
-      if (arg.constructor === String || arg.constructor === Number) {
-        strBuilder.push(arg)
-      } else {
-        break
-      }
-    }
-  }
-  if (i > 0) {
-    // create logArgs with what we have so far
-    strBuilder.push('\x1b[0m')
-    logArgs.push(strBuilder.join(''))
-  }
-  // append the rest
-  for (; i < args.length; i++) {
-    const arg = args[i]
-    /* istanbul ignore else */
-    if (!(arg instanceof Symbol)) {
-      logArgs.push(arg)
-    }
-  }
-  return logArgs
-}
-
-/* istanbul ignore next */
+/* c8 ignore start */
 const computeLoggingArgs = env.supportsColor
-  ? (env.isNode ? computeNodeLoggingArgs : computeBrowserLoggingArgs)
-  : computeNoColorLoggingArgs
+  ? computeBrowserLoggingArgs
+  : common.computeNoColorLoggingArgs
+/* c8 ignore stop */
 
 /**
  * @param {Array<string|Symbol|Object|number>} args
  */
 export const print = (...args) => {
   console.log(...computeLoggingArgs(args))
-  /* istanbul ignore next */
+  /* c8 ignore next */
   vconsoles.forEach((vc) => vc.print(args))
 }
 
-/* istanbul ignore next */
+/* c8 ignore start */
 /**
  * @param {Array<string|Symbol|Object|number>} args
  */
 export const warn = (...args) => {
   console.warn(...computeLoggingArgs(args))
-  args.unshift(ORANGE)
+  args.unshift(common.ORANGE)
   vconsoles.forEach((vc) => vc.print(args))
 }
+/* c8 ignore stop */
 
-/* istanbul ignore next */
 /**
  * @param {Error} err
  */
+/* c8 ignore start */
 export const printError = (err) => {
   console.error(err)
   vconsoles.forEach((vc) => vc.printError(err))
 }
+/* c8 ignore stop */
 
-/* istanbul ignore next */
 /**
  * @param {string} url image location
  * @param {number} height height of the image in pixel
  */
+/* c8 ignore start */
 export const printImg = (url, height) => {
   if (env.isBrowser) {
     console.log(
@@ -236,12 +133,13 @@ export const printImg = (url, height) => {
   }
   vconsoles.forEach((vc) => vc.printImg(url, height))
 }
+/* c8 ignore stop */
 
-/* istanbul ignore next */
 /**
  * @param {string} base64
  * @param {number} height
  */
+/* c8 ignore next 2 */
 export const printImgBase64 = (base64, height) =>
   printImg(`data:image/gif;base64,${base64}`, height)
 
@@ -250,7 +148,7 @@ export const printImgBase64 = (base64, height) =>
  */
 export const group = (...args) => {
   console.group(...computeLoggingArgs(args))
-  /* istanbul ignore next */
+  /* c8 ignore next */
   vconsoles.forEach((vc) => vc.group(args))
 }
 
@@ -259,38 +157,38 @@ export const group = (...args) => {
  */
 export const groupCollapsed = (...args) => {
   console.groupCollapsed(...computeLoggingArgs(args))
-  /* istanbul ignore next */
+  /* c8 ignore next */
   vconsoles.forEach((vc) => vc.groupCollapsed(args))
 }
 
 export const groupEnd = () => {
   console.groupEnd()
-  /* istanbul ignore next */
+  /* c8 ignore next */
   vconsoles.forEach((vc) => vc.groupEnd())
 }
 
-/* istanbul ignore next */
 /**
  * @param {function():Node} createNode
  */
+/* c8 ignore next 2 */
 export const printDom = (createNode) =>
   vconsoles.forEach((vc) => vc.printDom(createNode()))
 
-/* istanbul ignore next */
 /**
  * @param {HTMLCanvasElement} canvas
  * @param {number} height
  */
+/* c8 ignore next 2 */
 export const printCanvas = (canvas, height) =>
   printImg(canvas.toDataURL(), height)
 
-export const vconsoles = new Set()
+export const vconsoles = set.create()
 
-/* istanbul ignore next */
 /**
  * @param {Array<string|Symbol|Object|number>} args
  * @return {Array<Element>}
  */
+/* c8 ignore start */
 const _computeLineSpans = (args) => {
   const spans = []
   const currentStyle = new Map()
@@ -331,11 +229,12 @@ const _computeLineSpans = (args) => {
   }
   return spans
 }
+/* c8 ignore stop */
 
 const lineStyle =
   'font-family:monospace;border-bottom:1px solid #e2e2e2;padding:2px;'
 
-/* istanbul ignore next */
+/* c8 ignore start */
 export class VConsole {
   /**
    * @param {Element} dom
@@ -427,7 +326,7 @@ export class VConsole {
    * @param {Error} err
    */
   printError (err) {
-    this.print([RED, BOLD, err.toString()])
+    this.print([common.RED, common.BOLD, err.toString()])
   }
 
   /**
@@ -460,45 +359,16 @@ export class VConsole {
     })
   }
 }
+/* c8 ignore stop */
 
-/* istanbul ignore next */
 /**
  * @param {Element} dom
  */
+/* c8 ignore next */
 export const createVConsole = (dom) => new VConsole(dom)
 
-const loggingColors = [GREEN, PURPLE, ORANGE, BLUE]
-let nextColor = 0
-let lastLoggingTime = time.getUnixTime()
-
 /**
  * @param {string} moduleName
  * @return {function(...any):void}
  */
-export const createModuleLogger = (moduleName) => {
-  const color = loggingColors[nextColor]
-  const debugRegexVar = env.getVariable('log')
-  const doLogging = debugRegexVar !== null &&
-    (debugRegexVar === '*' || debugRegexVar === 'true' ||
-      new RegExp(debugRegexVar, 'gi').test(moduleName))
-  nextColor = (nextColor + 1) % loggingColors.length
-  moduleName += ': '
-
-  return !doLogging ? func.nop : (...args) => {
-    const timeNow = time.getUnixTime()
-    const timeDiff = timeNow - lastLoggingTime
-    lastLoggingTime = timeNow
-    print(
-      color,
-      moduleName,
-      UNCOLOR,
-      ...args.map((arg) =>
-        (typeof arg === 'string' || typeof arg === 'symbol')
-          ? arg
-          : JSON.stringify(arg)
-      ),
-      color,
-      ' +' + timeDiff + 'ms'
-    )
-  }
-}
+export const createModuleLogger = (moduleName) => common.createModuleLogger(print, moduleName)
