@@ -1,4 +1,4 @@
-/* global localStorage, addEventListener */
+/* eslint-env browser */
 
 /**
  * Isomorphic variable storage.
@@ -8,7 +8,7 @@
  * @module storage
  */
 
-/* istanbul ignore next */
+/* c8 ignore start */
 class VarStoragePolyfill {
   constructor () {
     this.map = new Map()
@@ -29,34 +29,44 @@ class VarStoragePolyfill {
     return this.map.get(key)
   }
 }
+/* c8 ignore stop */
 
-/* istanbul ignore next */
 /**
  * @type {any}
  */
 let _localStorage = new VarStoragePolyfill()
 let usePolyfill = true
 
+/* c8 ignore start */
 try {
   // if the same-origin rule is violated, accessing localStorage might thrown an error
-  /* istanbul ignore next */
   if (typeof localStorage !== 'undefined') {
     _localStorage = localStorage
     usePolyfill = false
   }
 } catch (e) { }
+/* c8 ignore stop */
 
-/* istanbul ignore next */
 /**
  * This is basically localStorage in browser, or a polyfill in nodejs
  */
+/* c8 ignore next */
 export const varStorage = _localStorage
 
-/* istanbul ignore next */
 /**
  * A polyfill for `addEventListener('storage', event => {..})` that does nothing if the polyfill is being used.
  *
  * @param {function({ key: string, newValue: string, oldValue: string }): void} eventHandler
  * @function
  */
+/* c8 ignore next */
 export const onChange = eventHandler => usePolyfill || addEventListener('storage', /** @type {any} */ (eventHandler))
+
+/**
+ * A polyfill for `removeEventListener('storage', event => {..})` that does nothing if the polyfill is being used.
+ *
+ * @param {function({ key: string, newValue: string, oldValue: string }): void} eventHandler
+ * @function
+ */
+/* c8 ignore next */
+export const offChange = eventHandler => usePolyfill || removeEventListener('storage', /** @type {any} */ (eventHandler))
