@@ -2,6 +2,8 @@ import { runTests } from './testing.js'
 import * as array from './array.test.js'
 import * as broadcastchannel from './broadcastchannel.test.js'
 import * as crypto from './crypto.test.js'
+import * as rabin from './hash/rabin.test.js'
+import * as sha256 from './hash/sha256.test.js'
 import * as logging from './logging.test.js'
 import * as string from './string.test.js'
 import * as encoding from './encoding.test.js'
@@ -20,6 +22,7 @@ import * as eventloop from './eventloop.test.js'
 import * as time from './time.test.js'
 import * as pair from './pair.test.js'
 import * as object from './object.test.js'
+import * as observable from './observable.test.js'
 import * as math from './math.test.js'
 import * as number from './number.test.js'
 import * as buffer from './buffer.test.js'
@@ -44,6 +47,8 @@ runTests({
   array,
   broadcastchannel,
   crypto,
+  rabin,
+  sha256,
   logging,
   string,
   encoding,
@@ -61,6 +66,7 @@ runTests({
   time,
   pair,
   object,
+  observable,
   math,
   number,
   buffer,
