@@ -3,16 +3,25 @@ import * as math from './math.js'
 import * as buffer from './buffer.js'
 import * as map from './map.js'
 import * as promise from './promise.js'
+import * as error from './error.js'
 
-/* istanbul ignore next */
+/* c8 ignore next */
 export const nottestingNotTested = () => {
   t.assert(false, 'This test should not be executed because the name doesnt start with "test"')
 }
 
+export const testAssertTyping = () => {
+  const q = Math.random()
+  const x = q === 0.3 ? null : { a: 4 } // this should always be an object
+  // t.assert(x.a === 4) - this will give a type error because the type is uncertain
+  t.assert(x)
+  t.assert(x.a === 4) // this works because x is asserted
+}
+
 /**
- * @param {t.TestCase} tc
+ * @param {t.TestCase} _tc
  */
-export const testComparing = tc => {
+export const testComparing = _tc => {
   t.compare({}, {})
   t.compare({ a: 4 }, { a: 4 }, 'simple compare (object)')
   t.compare([1, 2], [1, 2], 'simple compare (array)')
@@ -107,23 +116,34 @@ export const testComparing = tc => {
   })
 }
 
-export const testFailing = () => {
+export const testFailing = async () => {
   t.fails(() => {
     t.fail('This fail is expected')
   })
+  await t.promiseRejected(() => promise.reject(error.create('should be rejected')))
+  t.fails(() => {
+    t.fails(() => {})
+  })
+  await t.failsAsync(async () => {
+    await t.failsAsync(async () => { })
+  })
+  await t.promiseRejected(() =>
+    t.promiseRejected(() => promise.resolve())
+  )
 }
 
 export const testSkipping = () => {
   t.skip(false)
   t.assert(true)
   t.skip()
-  /* istanbul ignore next */
+  /* c8 ignore next */
   t.fail('should have skipped')
 }
 
 export const testAsync = async () => {
   await t.measureTimeAsync('time', () => promise.create(r => setTimeout(r)))
   await t.groupAsync('some description', () => promise.wait(1))
+  await t.promiseRejected(() => promise.reject(error.create('should be rejected')))
 }
 
 export const testRepeatRepetition = () => {
